\name{oncosign.sea}
\alias{oncosign.sea}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
OncoSign + SEA
}
\description{
This function bundles the oncosign and run.sea functions. For a detailed description of these functions see the respective man pages.
}
\usage{
oncosign.sea(property_file, cases = NULL, gam = NULL, max.levels = 3, min.alterations = 0.01)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{property_file}{
	Property file used by the Java implementation of OncoSign. If this file is available all other arguments are ignored.
}
  \item{cases}{
	Text file with list of cases/samples to analyze with OncoSign. 
	This file should contain one sample ID per line and sample IDs have to match those provided in the genomic alteration matrix (gam).
	If a property_file is not provided, this file is required.
}
  \item{gam}{
	Text file with all selected events (occurrences of genomic alterations) OncoSign will use.
	This file should be in a binary matrix format with samples as columns and events as rows (1 = altered, 0 = wild-type).
	First row is interpreted as header (sample IDs) and first column as event IDs (see example). Sample IDs have to match those provided in "cases".
	If a property_file is not provided, this file is required.
}
  \item{max.levels}{
	Max depth of the hierarchical structure of classes and sub-classes provided by OncoSign (default = 3).
	Note: maximal depth will be reached only if conditions for continuing stratification are met (see Ciriello et. al 2013).
}
  \item{min.alterations}{
	Minimum fraction of altered samples required for an event to be considered (default = 1\%).
}
}
\value{
  \item{data }{Copy of the "gam" object}
  \item{classes }{Table of OSC assignments: samples are listed as rows and column i specifies the assignment at level i.}
  \item{level<1,..,max.levels>}{level<i> component corresponds to the "significant" component returned by run.sea function at level i.}
}
\references{
Ciriello G., Miller M.L., Aksoy B.A., Senbabaoglu Y., Schultz N. & Sander C. (2013)
Emerging landscape of oncogenic signatures across human cancers. Nat Genetics 45, 1127-1133.
}
\author{
Giovanni Ciriello
}

\examples{

# \emph{run OncoSign with a predefined property file}
# os = oncosign.sea("oncosign.props")

# \emph{run OncoSign with explicit properties}
# os = oncosign.sea(cases = "cases.txt",gam = "gam.txt",max.levels = 2)

# \emph{result values}

# os$classes[1:4,]

#                V2      V3 V4
# TCGA-HT-7686 OSC.4           
# TCGA-HT-7687 OSC.1 OSC.1.3   
# TCGA-HT-7684 OSC.1 OSC.1.3   
# TCGA-HT-7688 OSC.4           

# \emph{oncosign.sea also return SEA significant events}

# os$level1[1:4,]

# 	 p            q	enriched.osc nsamples
# TERT 2.805146e-67 1.626985e-65        OSC.1      132
# TP53 3.094040e-60 8.972717e-59        OSC.4      138
# ATRX 4.931253e-50 9.533756e-49        OSC.4      138
# CIC  1.386498e-20 2.010422e-19        OSC.1      132


}

