\name{sea}
\alias{sea}
\title{
Signature Enrichement Analysis
}
\description{
Given a set of OncoSign classes (OSC), this function tests the selected events used by OncoSign 
for statistical significant enrichment in each OSC.
}
\usage{
sea(data, classes, level = 1, min.alterations = 0.01, max.alterations = 1, print.results = TRUE, maxQ = 0.05)
}

\arguments{
  \item{data}{
	Selected events used by OncoSign. The data has to be provided in a matrix format with samples as columns and events as rows.
	This object is also returned by the oncosign function ("<oncosign_object>$data").	
}
  \item{classes}{
	OSC assignments. A summary table with all OSC assignments is returned by the oncosign function and saved as "osc_assignments.txt".
	This object is also returned by the oncosign function ("<oncosign_object>$classes"))
}
  \item{level}{
	Level of the hierarchy from which OSC should be extracted (default = 1)
}
  \item{min.alterations}{
	Minimum fraction of altered samples required for an event to be considered (default = 1\%)
}
  \item{max.alterations}{
	Maximum fraction of altered samples required for an event to be considered (default = 100\%)
}
  \item{print.results}{
	Boolean, if TRUE results are printed in a table format under "sea_report_L<level>.txt" (default = TRUE)
}
  \item{maxQ}{
	Max q-value: events with q < maxQ will be used to define the oncogenic signatures characteristic of each class.
}
}

\value{
	\item{summary }{Summary of the subclass enrichment analysis: number of altered samples for each event and each OSC are reported along p/q-values or marginal enrichment (Fisher's test) for each event and the enriched OSC}
	\item{signatures }{Table reporting for each subclass the list of enriched events (Oncogenic Signatures). For each event X enriched in class Y, we report the percentage of samples with X in Y among all those in Y, and the percentage of samples with X in Y among all those with X.}
}
\references{
Ciriello G., Miller M.L., Aksoy B.A., Senbabaoglu Y., Schultz N. & Sander C. (2013)
Emerging landscape of oncogenic signatures across human cancers. Nat Genetics 45, 1127-1133.
}
\author{
Giovanni Ciriello
}

\examples{

# \emph{run sea using the output from oncosign}

# os = oncosign("oncosign.props")
# sea.results = sea(os$data,os$classes,level=1)

# \emph{events are sorted by q-values in ascending order}

# sea.results$summary[1:4,]
# 	 OSC.1 OSC.2 OSC.3 OSC.4            p            q enriched.osc	nsamples 
# TERT   124     0     0     1 2.805146e-67 1.626985e-65        OSC.1      132
# TP53    10     0     0   134 3.094040e-60 8.972717e-59        OSC.4      138
# ATRX     5     0     0   119 4.931253e-50 9.533756e-49        OSC.4      138
# CIC     53     0     0     0 1.386498e-20 2.010422e-19        OSC.1      132

# sea.results$signatures[1:4,]

#         Event  OSC.Percent Event.Percent
# OSC.1    TERT 	93.94		99.2
# OSC.1    CIC 	40.15		100
# OSC.1	 FUBP1 	18.94		100
# OSC.1	 EGFR 	18.18		92.31

}
